@@ -1,6 +1,6 @@
 package Sub::Spec::CmdLine;
 BEGIN {
-  $Sub::Spec::CmdLine::VERSION = '0.21';
+  $Sub::Spec::CmdLine::VERSION = '0.22';
 }
 # ABSTRACT: Access Perl subs via command line
 
@@ -13,20 +13,10 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(parse_argv gen_usage format_result run);
 
-# currently we cheat by only parsing a limited subset of schema. this is because
-# Data::Sah is not available yet.
+use Sub::Spec::Utils; # tmp, for _parse_schema
+
 sub _parse_schema {
-    my ($schema) = @_;
-
-    $schema = [$schema, {}] if !ref($schema);
-    die "BUG: Can't parse hash-form schema yet" if ref($schema) ne 'ARRAY';
-
-    my $type = $schema->[0];
-    $type =~ s/\*$// and $schema->[1]{required} = 1;
-    die "BUG: Can't handle type `$type` yet"
-        unless $type =~ /^(int|float|bool|str|array|hash|any)$/;
-
-    {type=>$type, attr_hashes=>[$schema->[1]]};
+    Sub::Spec::Utils::_parse_schema(@_);
 }
 
 sub parse_argv {
@@ -719,7 +709,7 @@ Sub::Spec::CmdLine - Access Perl subs via command line
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
